==> FHLBBS-4.2.tgz: maple/kaede.c <==
/*-------------------------------------------------------*/
/* kaede.c       ( SunOfBeach SOB BBS Ver 0.00 )         */
/*-------------------------------------------------------*/
/* target : Kaede's functions                            */
/* create : 96/03/23                                     */
/* update : 96/03/23                                     */
/*-------------------------------------------------------*/
/*
 * $Log: kaede.c,v $
 * Revision 1.1  1997/04/14 04:38:11  bbsroot
 * Initial revision
 *
 */

#include "bbs.h"

char *
kaede_prints(str)
  char *str;
{
  static char strbuf[272];
  char buf[16];
  register char *pos, *ptr, *strh = strbuf, *bufptr;

  strbuf[0] = '\0';

  while (strlen(strbuf) < 256)
  {
    if (!(pos = strstr(str, "\033*")))
    {
      strcpy(strh, str);        /* No more "ESC *", break */
      break;
    }

    if (pos != str)             /* "ESC *" is not the beginning of str */
    {
      while (str != pos)
        *(strh++) = *(str++);   /* copy the leading chars */
      *(strh) = '\0';
      continue;
    }

    ptr = str + 2;
    while (!(*ptr == '\0' || (*ptr != '+' && *ptr != '-' && *ptr != '.' &&
		(*ptr < '0' || *ptr > '9'))))
      ptr++;
#ifdef REALNAME
    if (*ptr != 's' && *ptr != 'r')     /* Illegal ESC sequence */
#else
    if (*ptr != 's')     /* Illegal ESC sequence */
#endif
    {
      str = ptr;
      continue;
    }

    bufptr = buf;
    *(bufptr++) = '%';
    pos += 2;
    while (pos != ptr)
      *(bufptr++) = *(pos++);
    *(bufptr++) = 's';
    *(bufptr++) = '\0';
    str = pos + 1;
#ifdef REALNAME
    sprintf(strh, buf, (*ptr == 'r') ? cuser.username : cuser.userid);
#else
    sprintf(strh, buf, cuser.userid);
#endif
    strh = strbuf + strlen(strbuf);
  }
  if (strlen(strbuf) >= 256)
    strbuf[255] = '\0';
  return strbuf;
}


/*
woju
Cross-fs rename()
*/

Rename(char* src, char* dst)
{
   char cmd[200];

   if (rename(src, dst) == 0)
      return 0;

   sprintf(cmd, "/bin/mv %s %s", src, dst);
   return system(cmd);

}



/*
woju
Cross-fs link()
*/

Link(char* src, char* dst)
{
   char cmd[200];

   if (link(src, dst) == 0)
      return 0;

   sprintf(cmd, "/bin/cp -R %s %s", src, dst);
   return system(cmd);
}


#ifdef SunOS

#include <syslog.h>

void
setenv(name, value, overwrite)
  const char *name;
  const char *value;
  int overwrite;
{
  if (overwrite || (getenv(name) == 0))
  {
    char *p;

    if ((p = malloc(strlen(name) + strlen(value) + 2)) == 0)
    {
      syslog(LOG_ERR, "out of memory\n");
      exit(1);
    }
    sprintf(p, "%s=%s", name, value);
    putenv(p);
  }
}
#endif

==> FHLBBS-5.3.tgz: maple/kaede.c <==
/*-------------------------------------------------------*/
/* kaede.c       ( SunOfBeach SOB BBS Ver 0.00 )         */
/*-------------------------------------------------------*/
/* target : Kaede's functions                            */
/* create : 96/03/23                                     */
/* update : 96/03/23                                     */
/*-------------------------------------------------------*/
/*
 * $Log: kaede.c,v $
 * Revision 1.1  1997/04/14 04:38:11  bbsroot
 * Initial revision
 *
 */

#include "bbs.h"

char *
kaede_prints(str)
  char *str;
{
  static char strbuf[272];
  char buf[16];
  register char *pos, *ptr, *strh = strbuf, *bufptr;

  strbuf[0] = '\0';

  while (strlen(strbuf) < 256)
  {
    if (!(pos = strstr(str, "\033*")))
    {
      strcpy(strh, str);        /* No more "ESC *", break */
      break;
    }

    if (pos != str)             /* "ESC *" is not the beginning of str */
    {
      while (str != pos)
        *(strh++) = *(str++);   /* copy the leading chars */
      *(strh) = '\0';
      continue;
    }

    ptr = str + 2;
    while (!(*ptr == '\0' || (*ptr != '+' && *ptr != '-' && *ptr != '.' &&
		(*ptr < '0' || *ptr > '9'))))
      ptr++;
#ifdef REALNAME
    if (*ptr != 's' && *ptr != 'r')     /* Illegal ESC sequence */
#else
    if (*ptr != 's')     /* Illegal ESC sequence */
#endif
    {
      str = ptr;
      continue;
    }

    bufptr = buf;
    *(bufptr++) = '%';
    pos += 2;
    while (pos != ptr)
      *(bufptr++) = *(pos++);
    *(bufptr++) = 's';
    *(bufptr++) = '\0';
    str = pos + 1;
#ifdef REALNAME
    sprintf(strh, buf, (*ptr == 'r') ? cuser.username : cuser.userid);
#else
    sprintf(strh, buf, cuser.userid);
#endif
    strh = strbuf + strlen(strbuf);
  }
  if (strlen(strbuf) >= 256)
    strbuf[255] = '\0';
  return strbuf;
}


/*
woju
Cross-fs rename()
*/

Rename(char* src, char* dst)
{
   char cmd[200];

   if (rename(src, dst) == 0)
      return 0;

   sprintf(cmd, "/bin/mv -f %s %s", src, dst);
   return system(cmd);

}



/*
woju
Cross-fs link()
*/

Link(char* src, char* dst)
{
   char cmd[200];

   if (link(src, dst) == 0)
      return 0;

   sprintf(cmd, "/bin/cp -R %s %s", src, dst);
   return system(cmd);
}


#ifdef SunOS

#include <syslog.h>

void
setenv(name, value, overwrite)
  const char *name;
  const char *value;
  int overwrite;
{
  if (overwrite || (getenv(name) == 0))
  {
    char *p;

    if ((p = malloc(strlen(name) + strlen(value) + 2)) == 0)
    {
      syslog(LOG_ERR, "out of memory\n");
      exit(1);
    }
    sprintf(p, "%s=%s", name, value);
    putenv(p);
  }
}
#endif
